@@ -56,7 +56,7 @@ def echo():
 
     async def echo(msg):
         if args.verbose:
-            msg_text = str(msg.pack())
+            msg_text = str(msg)
         else:
             msg_text = "{}: {}".format(msg.channel, msg.body)
         if args.label:
@@ -185,3 +185,33 @@ def bridge():
 
     asyncio.run(main())
     return 0
+
+def proxy():
+    import argparse
+
+    parser = argparse.ArgumentParser()
+    parser.add_argument("--public-port", type=int, default=7181)
+    parser.add_argument("--public-host", default="127.0.0.1")
+    parser.add_argument("--private-port", type=int, default=7181)
+    parser.add_argument("--private-host", default="127.0.0.1")
+    parser.add_argument("allowed_channels", nargs="+")
+    args = parser.parse_args()
+
+    if args.public_port == args.private_port and args.public_host == args.private_host:
+        print("The given arguments will proxy the server to itself. Aborting.")
+        return 1
+
+    import asyncio
+    import spoke
+
+    proxy = spoke.pubsub.proxy.Server(
+        args.allowed_channels,
+        conn_client_opts={"port": args.private_port, "host": args.private_host},
+        conn_server_opts={"port": args.public_port, "host": args.public_host},
+    )
+
+    try:
+        asyncio.run(proxy.run())
+    except KeyboardInterrupt:
+        pass
+    return 0
